<?php
/**
 * Elementor Ajax Woocommerce Products Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Ajax_Woocommerce_Products_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Ajax Woocommerce Products widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-ajax-woocommerce-products';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Ajax Woocommerce Products widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Ajax Woocommerce Products', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Ajax Woocommerce Products widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-categories kite-element-icon';
	}

	/**
	 * Get widget keywords.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords
	 */
	public function get_keywords() {
		return array( 'woocommerce', 'shop', 'products' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Ajax Woocommerce Products widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Ajax Woocommerce Products widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$product_cats = array();
		$product_tags = array();
		$cat_args     = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
		);

		$terms = get_terms( 'product_cat', $cat_args );
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) { // check is gallery plugin is active or not
			foreach ( $terms as $taxonomy ) {
					$product_cats[ $taxonomy->slug ] = $taxonomy->name;
			}
		}
		$tag_terms = get_terms( 'product_tag', $cat_args );
		if ( ! empty( $tag_terms ) && ! is_wp_error( $tag_terms ) ) { // check is gallery plugin is active or not
			foreach ( $tag_terms as $taxonomy ) {
					$product_tags[ $taxonomy->slug ] = $taxonomy->name;
			}
		}
		$accent_color = kite_opt( 'style-accent-color' );
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Ajax Woocommerce Products Tabs', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'position',
			array(
				'label'   => esc_html__( 'Tab Position', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'top'    => esc_html__( 'Top', 'pinkmart' ),
					'bottom' => esc_html__( 'Bottom', 'pinkmart' ),
				),
				'default' => 'top',
			)
		);
		$this->add_control(
			'alignment',
			array(
				'label'   => esc_html__( 'Alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'center' => esc_html__( 'Center', 'pinkmart' ),
					'left'   => esc_html__( 'Left', 'pinkmart' ),
					'right'  => esc_html__( 'Right', 'pinkmart' ),
				),
				'default' => 'center',
			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'shape',
			array(
				'label'   => esc_html__( 'Alignment', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'left'  => esc_html__( 'Before of title', 'pinkmart' ),
					'right' => esc_html__( 'After of title', 'pinkmart' ),
					'top'   => esc_html__( 'Top of title', 'pinkmart' ),
				),
				'default' => 'left',
			)
		);
		$this->add_control(
			'active_tab_color',
			array(
				'label'     => esc_html__( 'Active Tab Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .ajax_products_tab ul.vc_tta-tabs-list li.vc_active span' => 'color:{{VALUE}} !important',
					'{{WRAPPER}} .ajax_products_tab ul.vc_tta-tabs-list li.vc_active' => 'border-top-color:{{VALUE}} !important;border-bottom-color:{{VALUE}} !important;',
				),
			)
		);
		$this->add_control(
			'deactive_tab_color',
			array(
				'label'     => esc_html__( 'Deactive Tab Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .ajax_products_tab ul.vc_tta-tabs-list li span' => 'color:{{VALUE}}',
				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'repeater_section',
			array(
				'label' => esc_html__( 'Products Tabs', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'tab_title',
			array(
				'label'   => esc_html__( 'Title', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => 'Tab Title',
			)
		);
		$repeater->add_control(
			'tab_icon_check',
			array(
				'label'        => esc_html__( 'Tab Icon', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$repeater->add_control(
			'tab_icon',
			array(
				'label'     => esc_html__( 'Icon', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::ICON,
				'condition' => array(
					'tab_icon_check' => 'enable',
				),
			)
		);
		$repeater->add_control(
			'product_type',
			array(
				'label'   => esc_html__( 'Product Type', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'top_rated'    => esc_html__( 'Top Rated Products', 'pinkmart' ),
					'featured'     => esc_html__( 'Featured Products', 'pinkmart' ),
					'sale'         => esc_html__( 'onSale Products', 'pinkmart' ),
					'best_selling' => esc_html__( 'Best Selling Products', 'pinkmart' ),
					'recent'       => esc_html__( 'Recent Products', 'pinkmart' ),
					'deal'         => esc_html__( 'Deal Products', 'pinkmart' ),
				),
				'default' => 'top_rated',
			)
		);
		$repeater->add_control(
			'per_page',
			array(
				'label'       => esc_html__( 'Number of Products', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => '12',
				'description' => esc_html__( 'Number of Products per page', 'pinkmart' ),
			)
		);
		$repeater->add_control(
			'orderby',
			array(
				'label'   => esc_html__( 'Order by', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date'             => esc_html__( 'Date', 'pinkmart' ),
					'ID'               => esc_html__( 'ID', 'pinkmart' ),
					'author'           => esc_html__( 'Author', 'pinkmart' ),
					'title'            => esc_html__( 'Title', 'pinkmart' ),
					'modified'         => esc_html__( 'Modified', 'pinkmart' ),
					'rand'             => esc_html__( 'Random', 'pinkmart' ),
					'comment_count'    => esc_html__( 'Comment count', 'pinkmart' ),
					'menu_order'       => esc_html__( 'Menu order', 'pinkmart' ),
					'menu_order title' => esc_html__( 'Menu order & title', 'pinkmart' ),
					'include'          => esc_html__( 'Include', 'pinkmart' ),
				),
				'default' => 'date',
			)
		);
		$repeater->add_control(
			'order',
			array(
				'label'   => esc_html__( 'Sort order', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'DESC' => esc_html__( 'Descending', 'pinkmart' ),
					'ASC'  => esc_html__( 'Ascending', 'pinkmart' ),
				),
				'default' => 'DESC',
			)
		);
		$repeater->add_control(
			'product_cats',
			array(
				'label'       => esc_html__( 'product Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'all'    => esc_html__( 'All', 'pinkmart' ),
					'custom' => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'all',
			)
		);
		$repeater->add_control(
			'category',
			array(
				'label'       => esc_html__( 'Categories', 'pinkmart' ),
				'label_block' => true,
				'multiple'    => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'options'     => $product_cats,
				'default'     => '',
				'condition'   => array(
					'product_cats' => 'custom',
				),
			)
		);
		$repeater->add_control(
			'tags',
			array(
				'label'       => esc_html__( 'Product Tags', 'pinkmart' ),
				'label_block' => true,
				'multiple'    => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'options'     => $product_tags,
				'default'     => '',
			)
		);
		$repeater->add_control(
			'carousel',
			array(
				'label'       => esc_html__( 'Carousel/Grid Mode/List View', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'disable' => esc_html__( 'Grid', 'pinkmart' ),
					'enable'  => esc_html__( 'Carousel', 'pinkmart' ),
					'list'    => esc_html__( 'List View', 'pinkmart' ),
				),
				'default'     => 'disable',
			)
		);
		$repeater->add_control(
			'list_style',
			array(
				'label'       => esc_html__( 'List Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default'     => 'light',
				'condition'   => array(
					'carousel' => 'list',
				),
			)
		);
		$repeater->add_control(
			'columns',
			array(
				'label'       => esc_html__( 'Columns', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5',
				),
				'default'     => '3',
				'condition'   => array(
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'tablet_columns',
			array(
				'label'       => esc_html__( 'Columns in Tablet', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'2' => '2',
					'3' => '3',
					'4' => '4',
				),
				'default'     => '3',
				'condition'   => array(
					'carousel' => 'disable',
				),
			)
		);
		$repeater->add_control(
			'column_in_mobile',
			array(
				'label'       => esc_html__( 'Columns in Mobile', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'1' => '1',
					'2' => '2',
				),
				'default'     => '1',
				'condition'   => array(
					'carousel' => 'disable',
				),
			)
		);
		$repeater->add_control(
			'image_size',
			array(
				'label'       => esc_html__( 'Image Size', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'shop_catalog'   => esc_html__( 'Catalog Images', 'pinkmart' ),
					'shop_single'    => esc_html__( 'Single Product Image', 'pinkmart' ),
					'shop_thumbnail' => esc_html__( 'Product Thumbnails', 'pinkmart' ),
					'full'           => esc_html__( 'Full', 'pinkmart' ),
					'custom'         => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'shop_catalog',
				'condition'   => array(
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'image_size_width',
			array(
				'label'       => esc_html__( 'Image Size Width', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$repeater->add_control(
			'image_size_height',
			array(
				'label'       => esc_html__( 'Image Size Height', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$repeater->add_control(
			'image_size_crop',
			array(
				'label'        => esc_html__( 'Crop Image', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'condition'    => array(
					'image_size' => 'custom',
				),
			)
		);
		$repeater->add_control(
			'hover_image',
			array(
				'label'       => esc_html__( 'Hover Image', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default'     => 'show',
				'condition'   => array(
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'is_autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'on'  => esc_html__( 'On', 'pinkmart' ),
					'off' => esc_html__( 'Off', 'pinkmart' ),
				),
				'default'   => 'on',
				'condition' => array(
					'carousel' => 'enable',
				),
			)
		);
		$repeater->add_control(
			'countdown_activation',
			array(
				'label'        => esc_html__( 'Countdown timer', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => 'on',
				'default'      => '',
				'condition'    => array(
					'carousel' => array( 'enable', 'disable' ),
				),
			)
		);
		$repeater->add_control(
			'progressbar_activation',
			array(
				'label'        => esc_html__( 'Product Avalibilty', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => 'on',
				'default'      => '',
				'condition'    => array(
					'carousel' => array( 'enable', 'disable' ),
				),
			)
		);
		$repeater->add_control(
			'carousel_navigation',
			array(
				'label'        => esc_html__( 'Carousel Navigation', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'on',
				'default'	   => 'on',
				'condition'    => array(
					'carousel' => 'enable',
				),
			)
		);
		$repeater->add_control(
			'nav_style',
			array(
				'label'     => esc_html__( 'Navigations Style', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default'   => 'light',
				'condition' => array(
					'carousel' => 'enable',
					'carousel_navigation' => 'on'
				),
			)
		);
		$repeater->add_control(
			'style',
			array(
				'label'     => esc_html__( 'Style', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'style1'             => esc_html__( 'Buttons on hover', 'pinkmart' ),
					'style1-center'      => esc_html__( 'Buttons on hover - centered title', 'pinkmart' ),
					'style2'             => esc_html__( 'Info on hover', 'pinkmart' ),
					'style3'             => esc_html__( 'Info on click', 'pinkmart' ),
					'style4'             => esc_html__( 'Instant shop', 'pinkmart' ),
					'buttonsappearunder' => esc_html__( 'Buttons Appear Under', 'pinkmart' ),
				),
				'default'   => 'style1',
				'condition' => array(
					'carousel' => array( 'enable', 'disable' ),
				),
			)
		);
		$repeater->add_responsive_control(
			'show_card_variations',
			array(
				'label'        => esc_html__( 'Show Variations', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => true,
				'default' => true,
				'tablet_default' => true,
				'mobile_default' => true
			)
		);
		$repeater->add_control(
			'product_color_scheme',
			array(
				'label'   => esc_html__( 'Product Color Scheme', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default' => 'light',
			)
		);
		$repeater->add_control(
			'layout_mode',
			array(
				'label'     => esc_html__( 'Layout Mode', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'masonry' => esc_html__( 'Masonry', 'pinkmart' ),
					'fitRows' => esc_html__( 'Fit Rows', 'pinkmart' ),
				),
				'default'   => 'fitRows',
				'condition' => array(
					'carousel' => 'disable',
				),
			)
		);
		$repeater->add_control(
			'custom_hover_color',
			array(
				'label'     => esc_html__( 'Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => $accent_color,
				'condition' => array(
					'style' => array( 'style2', 'style3' ),
				),
			)
		);
		$repeater->add_control(
			'gutter',
			array(
				'label'        => esc_html__( 'Gutter', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => array(
					'carousel' => array( 'enable', 'disable' ),
				),
			)
		);
		$repeater->add_control(
			'border',
			array(
				'label'        => esc_html__( 'Border', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
				'description'  => esc_html__( 'Border around the product box', 'pinkmart' ),
				'condition'    => array(
					'carousel' => array( 'enable', 'disable' ),
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'quickview',
			array(
				'label'        => esc_html__( 'Quick View Button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style'    => array( 'style1', 'style1-center', 'style2', 'style4', 'buttonsappearunder' ),
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'wishlist',
			array(
				'label'        => esc_html__( 'Wishlist button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style'    => array( 'style1', 'style1-center', 'style2', 'buttonsappearunder' ),
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'compare',
			array(
				'label'        => esc_html__( 'Compare button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style'    => array( 'style1', 'style1-center', 'style2', 'buttonsappearunder' ),
					'carousel' => array( 'disable', 'enable' ),
				),
			)
		);
		$repeater->add_control(
			'badges',
			array(
				'label'        => esc_html__( 'Badges', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'carousel' => array( 'enable', 'disable' ),
				),
			)
		);
		$repeater->add_control(
			'hover_price',
			array(
				'label'        => esc_html__( 'hover price', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'condition'    => array(
					'style' => array( 'style2' ),
				),
			)
		);
		$repeater->add_control(
			'enterance_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fadein'           => esc_html__( 'FadeIn', 'pinkmart' ),
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'fadein',
			)
		);
		$repeater->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->add_control(
			'product_tabs',
			array(
				'label'       => esc_html__( 'WooCommerce Products Tabs', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'tab_title' => esc_html__( 'First Product Tab', 'pinkmart' ),
					),
					array(
						'tab_title' => esc_html__( 'Second Product Tab', 'pinkmart' ),
					),
				),
				'title_field' => '{{{ tab_title }}}',
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Ajax Woocommerce Products widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings              = $this->get_settings_for_display();
		$product_tab_shortcode = '';
		foreach ( $settings['product_tabs'] as $product_tab ) {
			$product_tab_shortcode .= $this->kite_generate_product_shortcode( $product_tab );
		}
		$shortcode = '[ajax_products_tab position="' . $settings['position'] . '" alignment="' . $settings['alignment'] . '" style="' . $settings['style'] . '" shape="' . $settings['shape'] . '" active_tab_color="' . $settings['active_tab_color'] . '" deactive_tab_color="' . $settings['deactive_tab_color'] . '"]' . $product_tab_shortcode . '[/ajax_products_tab]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return true;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings              = $this->get_settings_for_display();
		$product_tab_shortcode = '';
		foreach ( $settings['product_tabs'] as $product_tab ) {
			
			$product_tab_shortcode .= $this->kite_generate_product_shortcode( $product_tab );
		}
		$shortcode = '[ajax_products_tab position="' . $settings['position'] . '" alignment="' . $settings['alignment'] . '" style="' . $settings['style'] . '" shape="' . $settings['shape'] . '" active_tab_color="' . $settings['active_tab_color'] . '" deactive_tab_color="' . $settings['deactive_tab_color'] . '"]' . $product_tab_shortcode . '[/ajax_products_tab]';
		echo "$shortcode";

	}

	public function kite_generate_product_shortcode( $settings ) {
		if ( is_array( $settings['category'] ) ) {
			$category = implode( ',', $settings['category'] );
		} else {
			$category = $settings['category'];
		}

		if ( is_array( $settings['tags'] ) ) {
			$tags = implode( ',', $settings['tags'] );
		} else {
			$tags = $settings['tags'];
		}

		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		$settings['gutter'] = ( $settings['gutter'] == 'yes' ) ? '' : 'no';
		$toggles            = array(
			'quickview',
			'wishlist',
			'compare',
			'badges',
			'hover_price',
		);
		foreach ( $toggles as $toggle ) {
			$settings[ $toggle ] = ( $settings[ $toggle ] == 'enable' ) ? '' : 'disable';
		}
		
		$body_class[] = $settings['carousel_navigation'] == 'on' ? 'carousel-navigation-on' : 'carousel-navigation-off';

		$args = array(
			'tab_title'					=> $settings['tab_title'],
			'tab_icon_check'			=> $settings['tab_icon_check'],
			'tab_icon'					=> $settings['tab_icon'],
			'product_type'				=> $settings['product_type'],
			'per_page'					=> $settings['per_page'],
			'orderby'					=> $settings['orderby'],
			'order'						=> $settings['order'],
			'product_cats'				=> $settings['product_cats'],
			'category'					=> $category,
			'tags'						=> $tags,
			'carousel'					=> $settings['carousel'],
			'list_style'				=> $settings['list_style'],
			'columns'					=> $settings['columns'],
			'hover_image'				=> $settings['hover_image'],
			'is_autoplay'				=> $settings['is_autoplay'],
			'countdown_activation'		=> $settings['countdown_activation'],
			'progressbar_activation'	=> $settings['progressbar_activation'],
			'nav_style'					=> $settings['nav_style'],
			'style'						=> $settings['style'],
			'product_color_scheme'		=> $settings['product_color_scheme'],
			'layout_mode'				=> $settings['layout_mode'],
			'custom_hover_color'		=> $settings['custom_hover_color'],
			'hover_color'				=> 'custom-color',
			'gutter'					=> $settings['gutter'],
			'border'					=> $settings['border'],
			'quickview'					=> $settings['quickview'],
			'wishlist'					=> $settings['wishlist'],
			'compare'					=> $settings['compare'],
			'badges'					=> $settings['badges'],
			'hover_price'				=> $settings['hover_price'],
			'enterance_animation'		=> $settings['enterance_animation'],
			'responsive_animation'		=> $settings['responsive_animation'],
			'body_class'				=> implode( ' ', $body_class ),
			'column_in_mobile'			=> $settings['column_in_mobile'],
			'tablet_columns'			=> $settings['tablet_columns'],
			'show_card_variations_desktop'	=> $settings['show_card_variations'],
			'show_card_variations_tablet'	=> $settings['show_card_variations_tablet'],
			'show_card_variations_mobile'	=> $settings['show_card_variations_mobile'],
		);

		$shortcode = "[woocommerce_products_ajax ";
		foreach( $args as $key => $value ) {
			$shortcode .= $key . '="' . $value . '" ';
		}
		$shortcode .= $image_size ;
		$shortcode .= "]";

		return $shortcode;
	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Ajax_Woocommerce_Products_Widget() );
