<?php
/**
 * Elementor Animated Text Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Animated_Text_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Animated Text widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-animated-text';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Animated Text widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Animated Text', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Animated Text widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-text-area kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Animated Text widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Animated Text widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Animated Text', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'title',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'animatedtext_style',
			array(
				'label'   => esc_html__( 'Styles', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'with_image' => esc_html__( 'Animated text with Image background', 'pinkmart' ),
					'text_only'  => esc_html__( 'Animated text', 'pinkmart' ),
				),
				'default' => 'with_image',
			)
		);
		$this->add_control(
			'image_url',
			array(
				'label'     => esc_html__( 'Image URL', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'default'   => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
				'condition' => array(
					'animatedtext_style' => 'with_image',
				),
			)
		);
		$this->add_control(
			'title_front_color',
			array(
				'label'     => esc_html__( 'Front Text Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'condition' => array(
					'animatedtext_style' => 'with_image',
				),
				'selectors' => array(
					'{{WRAPPER}} .firsttitle' => 'color: {{VALUE}}',
				),
			)
		);
		$this->add_control(
			'title_back_color',
			array(
				'label'     => esc_html__( 'Text Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#272727',
				'selectors' => array(
					'{{WRAPPER}} .secondtitle' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => 'text_typography',
				'label'    => esc_html__( 'Text Typography', 'pinkmart' ),
				'scheme'   => \Elementor\Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .immediate',
			)
		);
		$this->add_control(
			'animatedtext_font_size',
			array(
				'label'       => esc_html__( 'Animated Text Height(vw)', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::NUMBER,
				'min'         => 1,
				'description' => esc_html__( 'Enter the size of height (minimum possible value is equal to 1), for example 14.', 'pinkmart' ),
				'default'     => 30,
			)
		);
		$this->add_control(
			'animatedtext_speed',
			array(
				'label'   => esc_html__( 'Animation Duration', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'4'  => esc_html__( 'Faster', 'pinkmart' ),
					'8'  => esc_html__( 'Fast', 'pinkmart' ),
					'12' => esc_html__( 'Medium', 'pinkmart' ),
					'16' => esc_html__( 'Slow', 'pinkmart' ),
					'24' => esc_html__( 'Slower', 'pinkmart' ),
				),
				'default' => '4',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Animated Text widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( $settings['animatedtext_style'] == 'with_image' ) {
			$image = 'style="with_image" image_url="' . $settings['image_url']['id'] . '" title_front_color="' . $settings['title_front_color'] . '"';
		} else {
			$image = 'animatedtext_style="text_only"';
		}
		$shortcode = '[animatedtext title="' . $settings['title'] . '" ' . $image . ' title_back_color="' . $settings['title_back_color'] . '" animatedtext_font_size="' . $settings['animatedtext_font_size'] . '" animatedtext_speed="' . $settings['animatedtext_speed'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( $settings['animatedtext_style'] == 'with_image' ) {
			$image = 'style="with_image" image_url="' . $settings['image_url']['id'] . '" title_front_color="' . $settings['title_front_color'] . '"';
		} else {
			$image = 'animatedtext_style="text_only"';
		}
		$shortcode = '[animatedtext title="' . $settings['title'] . '" ' . $image . ' title_back_color="' . $settings['title_back_color'] . '" animatedtext_font_size="' . $settings['animatedtext_font_size'] . '" animatedtext_speed="' . $settings['animatedtext_speed'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Animated_Text_Widget() );
