<?php
/**
 * Elementor Blog Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Blog_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Blog widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Blog widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog - Card Style', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-group kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Blog widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$posts_cats = array();
		$cat_args   = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
		);

		$terms = get_terms( 'category', $cat_args );

		foreach ( $terms as $taxonomy ) {
			 $posts_cats[ $taxonomy->slug ] = $taxonomy->name;
		}
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Blog', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'blog_column',
			array(
				'label'   => esc_html__( 'Number of columns', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'3' => esc_html__( 'Three', 'pinkmart' ),
					'4' => esc_html__( 'Four', 'pinkmart' ),
				),
				'default' => '3',
			)
		);
		$this->add_control(
			'blog_filter',
			array(
				'label'       => esc_html__( 'Blog Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'all'    => esc_html__( 'All', 'pinkmart' ),
					'custom' => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'all',
			)
		);
		$this->add_control(
			'blog_category',
			array(
				'label'       => esc_html__( 'Category', 'pinkmart' ),
				'label_block' => true,
				'multiple'    => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'options'     => $posts_cats,
				'default'     => '',
				'condition'   => array(
					'blog_filter' => 'custom',
				),
			)
		);
		$this->add_control(
			'blog_style',
			array(
				'label'   => esc_html__( 'Blog Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'inline_interaction' => esc_html__( 'Inline interaction', 'pinkmart' ),
					'popup_interaction'  => esc_html__( 'Pop-up interaction', 'pinkmart' ),
				),
				'default' => 'inline_interaction',
			)
		);
		$this->add_control(
			'blog_layout_mode',
			array(
				'label'   => esc_html__( 'Layout Mode', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'masonry' => esc_html__( 'Masonry', 'pinkmart' ),
					'fitRows' => esc_html__( 'Fit Rows', 'pinkmart' ),
				),
				'default' => 'masonry',
			)
		);
		$this->add_control(
			'blog_image_size',
			array(
				'label'   => esc_html__( 'Image size', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'large'  => esc_html__( 'Large', 'pinkmart' ),
					'scaled' => esc_html__( 'Scaled', 'pinkmart' ),
				),
				'default' => 'large',
			)
		);
		$this->add_control(
			'blog_post_number',
			array(
				'label'      => esc_html__( 'Number of posts', 'pinkmart' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'num' ),
				'range'      => array(
					'num' => array(
						'min'  => 1,
						'max'  => 30,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'num',
					'size' => 16,
				),
			)
		);
		$this->add_control(
			'blog_category_author',
			array(
				'label'   => esc_html__( 'Blog Author & Comments', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Visible', 'pinkmart' ),
					'no'  => esc_html__( 'Invisible', 'pinkmart' ),
				),
				'default' => 'yes',
			)
		);
		$this->add_control(
			'blog_category_visibility',
			array(
				'label'   => esc_html__( 'Category Visibility', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Visible', 'pinkmart' ),
					'no'  => esc_html__( 'Invisible', 'pinkmart' ),
				),
				'default' => 'yes',
			)
		);
		$this->add_control(
			'blog_foreground_color',
			array(
				'label'       => esc_html__( 'Text Color', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default'     => 'dark',
				'description' => esc_html__( 'Choose dark or light style of text', 'pinkmart' ),
			)
		);
		$this->add_control(
			'blog_more_button',
			array(
				'label'        => esc_html__( 'Disable Load More Button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'disable',
				'default'      => 'disable',
			)
		);
		$this->add_control(
			'load_more_style',
			array(
				'label'     => esc_html__( 'Load more style', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => array(
					'dark'       => esc_html__( 'Dark', 'pinkmart' ),
					'lightstyle' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default'   => 'dark',
				'condition' => array(
					'blog_more_button' => '',
				),
			)
		);
		$this->add_control(
			'blog_background_color',
			array(
				'label'     => esc_html__( 'Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .blog-masonry-container' => 'background-color:{{VALUE}}',
					'{{WRAPPER}} .blog-masonry-container .blog-masonry-content .like-count,{{WRAPPER}} .blog-masonry-container .blog-masonry-content .post-share:hover .share-hover i' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'quote_blog_background_color',
			array(
				'label'     => esc_html__( 'Quote Post Background Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#073B87',
				'selectors' => array(
					'{{WRAPPER}} .blog-masonry-container.kt_quote' => 'background-color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'quote_blog_text_color',
			array(
				'label'     => esc_html__( 'Quote Post text Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#fff',
				'selectors' => array(
					'{{WRAPPER}} .blog-masonry-container.kt_quote .icon, {{WRAPPER}} .blog-masonry-container.kt_quote .blog-masonry-content .blog-excerpt,{{WRAPPER}} .blog-masonry-container.kt_quote .blog-masonry-content .quote-author' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'blog_multimedia_icon_style',
			array(
				'label'   => esc_html__( 'Video & sound icon style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default' => 'light',
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'enterance_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'fadeinfrombottom',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['blog_category'] ) ) {
			$blog_category = implode( ',', $settings['blog_category'] );
		} else {
			$blog_category = $settings['blog_category'];
		}
		$shortcode = '[kt_masonry_blog blog_column="' . $settings['blog_column'] . '" blog_filter="' . $settings['blog_filter'] . '" blog_category="' . $blog_category . '" blog_style="' . $settings['blog_style'] . '" blog_layout_mode="' . $settings['blog_layout_mode'] . '" blog_image_size="' . $settings['blog_image_size'] . '" blog_post_number="' . $settings['blog_post_number']['size'] . '" blog_category_author="' . $settings['blog_category_author'] . '" blog_category_visibility="' . $settings['blog_category_visibility'] . '" blog_foreground_color="' . $settings['blog_foreground_color'] . '" blog_more_button="' . $settings['blog_more_button'] . '" load_more_style="' . $settings['load_more_style'] . '" blog_background_color="' . $settings['blog_background_color'] . '" quote_blog_background_color="' . $settings['quote_blog_background_color'] . '" quote_blog_text_color="' . $settings['quote_blog_text_color'] . '" blog_multimedia_icon_style="' . $settings['blog_multimedia_icon_style'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['blog_category'] ) ) {
			$blog_category = implode( ',', $settings['blog_category'] );
		} else {
			$blog_category = $settings['blog_category'];
		}
		$shortcode = '[kt_masonry_blog blog_column="' . $settings['blog_column'] . '" blog_filter="' . $settings['blog_filter'] . '" blog_category="' . $blog_category . '" blog_style="' . $settings['blog_style'] . '" blog_layout_mode="' . $settings['blog_layout_mode'] . '" blog_image_size="' . $settings['blog_image_size'] . '" blog_post_number="' . $settings['blog_post_number']['size'] . '" blog_category_author="' . $settings['blog_category_author'] . '" blog_category_visibility="' . $settings['blog_category_visibility'] . '" blog_foreground_color="' . $settings['blog_foreground_color'] . '" blog_more_button="' . $settings['blog_more_button'] . '" load_more_style="' . $settings['load_more_style'] . '" blog_background_color="' . $settings['blog_background_color'] . '" quote_blog_background_color="' . $settings['quote_blog_background_color'] . '" quote_blog_text_color="' . $settings['quote_blog_text_color'] . '" blog_multimedia_icon_style="' . $settings['blog_multimedia_icon_style'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Blog_Widget() );
