<?php
/**
 * Elementor Contact Form 7 Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Contact_Form_7_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Contact Form 7 widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-contact-form-7';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Contact Form 7 widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Form 7', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Contact Form 7 widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-email-field kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Contact Form 7 widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Contact Form 7 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$contact_forms = array();
		$args          = array(
			'post_type'      => 'wpcf7_contact_form',
			'posts_per_page' => -1,
		);
		$contact_posts = new WP_Query( $args );
		if ( $contact_posts->have_posts() ) {
			while ( $contact_posts->have_posts() ) {
				$contact_posts->the_post();
				$contact_forms[ get_the_ID() ] = get_the_title();
			}
		}
		wp_reset_postdata();
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Contact Form 7', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'form_id',
			array(
				'label'   => esc_html__( 'Select Contact Form', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $contact_forms,
			)
		);
		$this->add_control(
			'form_color_style',
			array(
				'label'       => esc_html__( 'Form Color Style', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'light_styles' => esc_html__( 'Light', 'pinkmart' ),
					'dark_styles'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default'     => 'light_styles',
			)
		);
		$this->add_control(
			'form_align',
			array(
				'label'       => esc_html__( 'Form Align', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'left'   => esc_html__( 'Left', 'pinkmart' ),
					'center' => esc_html__( 'Center', 'pinkmart' ),
				),
				'default'     => 'left',
			)
		);
		$this->add_control(
			'form_width_style',
			array(
				'label'   => esc_html__( 'Form Width Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'boxed'     => esc_html__( 'Boxed', 'pinkmart' ),
					'fullwidth' => esc_html__( 'fullwidth', 'pinkmart' ),
				),
				'default' => 'boxed',
			)
		);
		$this->add_control(
			'form_style',
			array(
				'label'   => esc_html__( 'Form Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'one_column' => esc_html__( 'One Column', 'pinkmart' ),
					'two_column' => esc_html__( 'Two Columns', 'pinkmart' ),
				),
				'default' => 'one_column',
			)
		);
		$this->add_control(
			'button_style',
			array(
				'label'   => esc_html__( 'Button Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'pinkmart' ),
					'style2' => esc_html__( 'Style 2', 'pinkmart' ),
					'style3' => esc_html__( 'Style 3', 'pinkmart' ),
				),
				'default' => 'style1',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Contact Form 7 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( empty( $settings['form_id'] ) ) {
			return;
		}
		$classes    = array( $settings['form_color_style'], $settings['form_width_style'], $settings['form_style'], $settings['button_style'], $settings['form_align'] );
		$html_class = implode( ' ', $classes );
		$shortcode  = '[contact-form-7 id="' . $settings['form_id'] . '" html_class="' . $html_class . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( empty( $settings['form_id'] ) ) {
			return;
		}
		$classes    = array( $settings['form_color_style'], $settings['form_width_style'], $settings['form_style'], $settings['button_style'], $settings['form_align'] );
		$html_class = implode( ' ', $classes );
		$shortcode  = '[contact-form-7 id="' . $settings['form_id'] . '" html_class="' . $html_class . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Contact_Form_7_Widget() );
