<?php
/**
 * Elementor Counter Box Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Counter_Box_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Counter Box widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-counter-box';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Counter Box widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Counter Box', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Counter Box widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-counter kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Counter Box widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Counter Box widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Counter Box', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'counter_number',
			array(
				'label' => esc_html__( 'Number', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'counter_number_color',
			array(
				'label'     => esc_html__( "Counter's Number Color", 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .counterboxnumber' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'counter_text',
			array(
				'label' => esc_html__( 'Counter title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'counter_text2',
			array(
				'label' => esc_html__( 'Counter text', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'counter_text_color',
			array(
				'label'     => esc_html__( 'Title Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .counterboxdetails, {{WRAPPER}} .counterboxdetails2' => 'color:{{VALUE}}',
				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'counter_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fade-in'        => esc_html__( 'FadeIn', 'pinkmart' ),
					'fade-in-bottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fade-in-top'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fade-in-right'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fade-in-left'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'grow-in'        => esc_html__( 'Grow In', 'pinkmart' ),
					'none'           => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'none',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Disable Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'disable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Counter Box widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings  = $this->get_settings_for_display();
		$shortcode = '[conterbox counter_number="' . $settings['counter_number'] . '" counter_number_color="' . $settings['counter_number_color'] . '" counter_text="' . $settings['counter_text'] . '" counter_text2="' . $settings['counter_text2'] . '" counter_text_color="' . $settings['counter_text_color'] . '" counter_animation="' . $settings['counter_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" ]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings  = $this->get_settings_for_display();
		$shortcode = '[conterbox counter_number="' . $settings['counter_number'] . '" counter_number_color="' . $settings['counter_number_color'] . '" counter_text="' . $settings['counter_text'] . '" counter_text2="' . $settings['counter_text2'] . '" counter_text_color="' . $settings['counter_text_color'] . '" counter_animation="' . $settings['counter_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" ]';
		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Counter_Box_Widget() );
