<?php
/**
 * Elementor Gallery Carousel Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Gallery_Carousel_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Gallery Carousel widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-gallery-carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Gallery Carousel widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Gallery Carousel', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Gallery Carousel widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-photo-library kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Gallery Carousel widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Gallery Carousel widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$gallery_cats = array();
		$cat_args     = array(
			'orderby'    => 'term_id',
			'order'      => 'ASC',
			'hide_empty' => false,
		);

		$terms = get_terms( 'gallery_cat', $cat_args );
		if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) { // check is gallery plugin is active or not
			foreach ( $terms as $taxonomy ) {
					$gallery_cats[ $taxonomy->slug ] = $taxonomy->name;
			}
		}
		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Gallery Carousel', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'visible_items',
			array(
				'label'   => esc_html__( 'Visible Items', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5',
					'6' => '6',
					'7' => '7',
					'8' => '8',
				),
				'default' => '1',
			)
		);
		$this->add_control(
			'gutter',
			array(
				'label'        => esc_html__( 'Remove Gutter', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'no',
				'default'      => 'no',
				'description'  => esc_html__( 'Remove gutter between items', 'pinkmart' ),
			)
		);
		$this->add_control(
			'naxt_prev_btn',
			array(
				'label'   => esc_html__( 'Navigation Buttons Visibility', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'show' => esc_html__( 'Enable', 'pinkmart' ),
					'hide' => esc_html__( 'Disable', 'pinkmart' ),
				),
				'default' => 'show',
			)
		);
		$this->add_control(
			'nav_style',
			array(
				'label'   => esc_html__( 'Navigation Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'custom_hover_color',
			array(
				'label'     => esc_html__( 'Custom hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .carousel .swiper-slide .image-container:before' => 'background-color: {{VALUE}}',
				),
			)
		);

		$this->add_control(
			'is_autoplay',
			array(
				'label'   => esc_html__( 'Autoplay', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'on'  => esc_html__( 'On', 'pinkmart' ),
					'off' => esc_html__( 'Off', 'pinkmart' ),
				),
				'default' => 'on',
			)
		);
		$this->add_control(
			'portfolio_filter',
			array(
				'label'       => esc_html__( 'Gallery Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'all'    => esc_html__( 'All', 'pinkmart' ),
					'custom' => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'all',
			)
		);
		$this->add_control(
			'filters',
			array(
				'label'       => esc_html__( 'Gallery custom Categories', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'multiple'    => true,
				'options'     => $gallery_cats,
				'condition'   => array(
					'portfolio_filter' => 'custom',
				),
			)
		);
		$this->add_control(
			'enterance_animation',
			array(
				'label'   => esc_html__( 'Entrance animation', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default' => 'fadeinfrombottom',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Gallery Carousel widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['filters'] ) ) {
			$filters = implode( ',', $settings['filters'] );
		} else {
			$filters = $settings['filters'];
		}
		$shortcode = '[gallery_carousel visible_items="' . $settings['visible_items'] . '" gutter="' . $settings['gutter'] . '" naxt_prev_btn="' . $settings['naxt_prev_btn'] . '" nav_style="' . $settings['nav_style'] . '" hover_color="custom" custom_hover_color="' . $settings['custom_hover_color'] . '" is_autoplay="' . $settings['is_autoplay'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" portfolio_filter="' . $settings['portfolio_filter'] . '" filters="' . $filters . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( is_array( $settings['filters'] ) ) {
			$filters = implode( ',', $settings['filters'] );
		} else {
			$filters = $settings['filters'];
		}
		$shortcode = '[gallery_carousel visible_items="' . $settings['visible_items'] . '" gutter="' . $settings['gutter'] . '" naxt_prev_btn="' . $settings['naxt_prev_btn'] . '" nav_style="' . $settings['nav_style'] . '" hover_color="custom" custom_hover_color="' . $settings['custom_hover_color'] . '" is_autoplay="' . $settings['is_autoplay'] . '" enterance_animation="' . $settings['enterance_animation'] . '" responsive_animation="' . $settings['responsive_animation'] . '" portfolio_filter="' . $settings['portfolio_filter'] . '" filters="' . $filters . '"]';

		echo "$shortcode";

	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Gallery_Carousel_Widget() );
