<?php
/**
 * Elementor Single Product Widget.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Single_Product_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Single Product widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-single-product';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Single Product widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Single Product', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Single Product widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info kite-element-icon';
	}

	/**
	 * Get widget keywords.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords
	 */
	public function get_keywords() {
		return array( 'woocommerce', 'shop', 'product' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Single Product widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Single Product widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$args = array(
			'post_type'      => 'product',
			'posts_per_page' => -1,
		);

		$loop     = new WP_Query( $args );
		$products = array();
		while ( $loop->have_posts() ) :
			$loop->the_post();
			$products[ get_the_ID() ] = get_the_title();
		endwhile;
		wp_reset_postdata();

		$accent_color = kite_opt( 'style-accent-color' );

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Single Product', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'product_id',
			array(
				'label'   => esc_html__( 'Select Product', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => $products,
			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'style1'             => esc_html__( 'Buttons on hover', 'pinkmart' ),
					'style1-center'      => esc_html__( 'Buttons on hover - centered title', 'pinkmart' ),
					'style2'             => esc_html__( 'Info on hover', 'pinkmart' ),
					'style3'             => esc_html__( 'Info on click', 'pinkmart' ),
					'style4'             => esc_html__( 'Instant shop', 'pinkmart' ),
					'buttonsappearunder' => esc_html__( 'Buttons Appear Under', 'pinkmart' ),
				),
				'default' => 'style1',
			)
		);
		$this->add_responsive_control(
			'show_card_variations',
			array(
				'label'        => esc_html__( 'Show Variations', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => true,
				'default' => true,
				'tablet_default' => true,
				'mobile_default' => true
			)
		);
		$this->add_control(
			'product_color_scheme',
			array(
				'label'   => esc_html__( 'Product Color Scheme', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'light' => esc_html__( 'Light', 'pinkmart' ),
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
				),
				'default' => 'light',
			)
		);
		$this->add_control(
			'image_size',
			array(
				'label'       => esc_html__( 'Image Size', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'shop_catalog'   => esc_html__( 'Catalog Images', 'pinkmart' ),
					'shop_single'    => esc_html__( 'Single Product Image', 'pinkmart' ),
					'shop_thumbnail' => esc_html__( 'Product Thumbnails', 'pinkmart' ),
					'full'           => esc_html__( 'Full', 'pinkmart' ),
					'custom'         => esc_html__( 'Custom', 'pinkmart' ),
				),
				'default'     => 'shop_catalog',
			)
		);
		$this->add_control(
			'image_size_width',
			array(
				'label'       => esc_html__( 'Image Size Width', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_height',
			array(
				'label'       => esc_html__( 'Image Size Height', 'pinkmart' ),
				'label_block' => false,
				'type'        => \Elementor\Controls_Manager::TEXT,
				'condition'   => array(
					'image_size' => 'custom',
				),
			)
		);

		$this->add_control(
			'image_size_crop',
			array(
				'label'        => esc_html__( 'Crop Image', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'condition'    => array(
					'image_size' => 'custom',
				),
			)
		);
		$this->add_control(
			'hover_image',
			array(
				'label'       => esc_html__( 'Hover Image', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'show' => esc_html__( 'Show', 'pinkmart' ),
					'hide' => esc_html__( 'Hide', 'pinkmart' ),
				),
				'default'     => 'show',
			)
		);
		$this->add_control(
			'countdown_activation',
			array(
				'label'        => esc_html__( 'Countdown timer', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => 'on',
				'default'      => '',
			)
		);
		$this->add_control(
			'progressbar_activation',
			array(
				'label'        => esc_html__( 'Product Avalibilty', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'ON', 'pinkmart' ),
				'label_off'    => esc_html__( 'OFF', 'pinkmart' ),
				'return_value' => 'on',
				'default'      => '',
			)
		);
		$this->add_control(
			'custom_hover_color',
			array(
				'label'     => esc_html__( 'Hover Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => $accent_color,
				'condition' => array(
					'style' => array( 'style2', 'style3' ),
				),
			)
		);
		$this->add_control(
			'border',
			array(
				'label'        => esc_html__( 'Border', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => '',
				'description'  => esc_html__( 'Border around the product box', 'pinkmart' ),
			)
		);
		$this->add_control(
			'quickview',
			array(
				'label'        => esc_html__( 'Quick View Button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style' => array( 'style1', 'style1-center', 'style2', 'style4', 'buttonsappearunder' ),
				),
			)
		);
		$this->add_control(
			'wishlist',
			array(
				'label'        => esc_html__( 'Wishlist button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style' => array( 'style1', 'style1-center', 'style2', 'buttonsappearunder' ),
				),
			)
		);
		$this->add_control(
			'compare',
			array(
				'label'        => esc_html__( 'Compare button', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
				'condition'    => array(
					'style' => array( 'style1', 'style1-center', 'style2', 'buttonsappearunder' ),
				),
			)
		);
		$this->add_control(
			'badges',
			array(
				'label'        => esc_html__( 'Badges', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'pinkmart' ),
				'label_off'    => esc_html__( 'No', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'enable',
			)
		);
		$this->add_control(
			'hover_price',
			array(
				'label'        => esc_html__( 'hover price', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
				'condition'    => array(
					'style' => array( 'style2' ),
				),
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'animation_section',
			array(
				'label' => esc_html__( 'Animation', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'enterance_animation',
			array(
				'label'       => esc_html__( 'Entrance animation', 'pinkmart' ),
				'label_block' => true,
				'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => array(
					'fadeinfrombottom' => esc_html__( 'FadeIn From Bottom', 'pinkmart' ),
					'fadeinfromtop'    => esc_html__( 'FadeIn From Top', 'pinkmart' ),
					'fadeinfromright'  => esc_html__( 'FadeIn From Right', 'pinkmart' ),
					'fadeinfromleft'   => esc_html__( 'FadeIn From Left', 'pinkmart' ),
					'zoomin'           => esc_html__( 'Zoom-in', 'pinkmart' ),
					'default'          => esc_html__( 'No Animation', 'pinkmart' ),
				),
				'default'     => 'fadeinfrombottom',
			)
		);
		$this->add_control(
			'responsive_animation',
			array(
				'label'        => esc_html__( 'Animation in Responsive', 'pinkmart' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'pinkmart' ),
				'label_off'    => esc_html__( 'Disable', 'pinkmart' ),
				'return_value' => 'enable',
				'default'      => 'disable',
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Single Product widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$shortcode = $this->kite_generate_shortcode( $settings );
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		$shortcode = $this->kite_generate_shortcode( $settings );
		echo wp_kses( $shortcode, $GLOBALS['kite-allowed-tags'] );

	}

	public function kite_generate_shortcode( $settings ) {

		if ( $settings['image_size'] == 'custom' ) {
			$image_size = 'image_size="custom" image_size_width="' . $settings['image_size_width'] . '" image_size_height="' . $settings['image_size_height'] . '" image_size_crop="' . $settings['image_size_crop'] . '"';
		} else {
			$image_size = 'image_size="' . $settings['image_size'] . '"';
		}

		$toggles            = array(
			'quickview',
			'wishlist',
			'compare',
			'badges',
			'hover_price',
		);
		foreach ( $toggles as $toggle ) {
			$settings[ $toggle ] = ( $settings[ $toggle ] == 'enable' ) ? '' : 'disable';
		}

		$args = array(
			'product_id'				=> $settings['product_id'],
			'hover_image'				=> $settings['hover_image'],
			'countdown_activation'		=> $settings['countdown_activation'],
			'progressbar_activation'	=> $settings['progressbar_activation'],
			'style'						=> $settings['style'],
			'product_color_scheme'		=> $settings['product_color_scheme'],
			'custom_hover_color'		=> $settings['custom_hover_color'],
			'hover_color'				=> 'custom',
			'border'					=> $settings['border'],
			'quickview'					=> $settings['quickview'],
			'wishlist'					=> $settings['wishlist'],
			'compare'					=> $settings['compare'],
			'badges'					=> $settings['badges'],
			'hover_price'				=> $settings['hover_price'],
			'enterance_animation'		=> $settings['enterance_animation'],
			'responsive_animation'		=> $settings['responsive_animation'],
			'show_card_variations_desktop'	=> $settings['show_card_variations'],
			'show_card_variations_tablet'	=> $settings['show_card_variations_tablet'],
			'show_card_variations_mobile'	=> $settings['show_card_variations_mobile'],
		);
		$shortcode = "[product ";
		foreach( $args as $key => $value ) {
			$shortcode .= $key . '="' . $value . '" ';
		}
		$shortcode .= $image_size ;
		$shortcode .= "]";

		return $shortcode;
	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Single_Product_Widget() );
