<?php
/**
 * Elementor Team Member Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Team_Member_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Team Member widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-team-member';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team Member widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Member', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team Member widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-person kite-element-icon';
	}

	/**
	 * Get widget keywords.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget keywords
	 */
	public function get_keywords() {
		return array( 'team', 'member', 'person' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team Member widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Team Member widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			array(
				'label' => esc_html__( 'Content', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'name',
			array(
				'label'       => esc_html__( 'Name', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Member Name', 'pinkmart' ),
			)
		);
		$this->add_control(
			'job_title',
			array(
				'label'       => esc_html__( 'Job', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Member Job', 'pinkmart' ),
			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'team_color',
			array(
				'label'     => esc_html__( 'Team Member Color', 'pinkmart' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'default'   => '#cccccc',
				'selectors' => array(
					'{{WRAPPER}} .team-member:hover .member-plus' => 'background-color:{{VALUE}}',
					'{{WRAPPER}} .team-member .member-line' => 'background-color:{{VALUE}}',
					'{{WRAPPER}} .team-member .icons li:hover a' => 'color:{{VALUE}}',
				),
			)
		);
		$this->add_control(
			'image',
			array(
				'label'   => esc_html__( 'Optional URL of member\'s image', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$this->add_control(
			'signature',
			array(
				'label'   => esc_html__( 'Optional URL of the person\'s signature', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => '',
				),
			)
		);
		$this->add_control(
			'description',
			array(
				'label' => esc_html__( 'Content', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
				'rows'  => 5,
			)
		);
		$this->add_control(
			'url',
			array(
				'label'         => esc_html__( 'Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->add_control(
			'elementor_url_title',
			array(
				'label' => esc_html__( 'Link Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$this->add_control(
			'team_icon1',
			array(
				'label'       => esc_html__( 'Select 1st icon', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::ICON,
				'description' => esc_html__( 'Choose an icon for team member icon 1', 'pinkmart' ),
			)
		);
		$this->add_control(
			'team_icon1_url',
			array(
				'label'         => esc_html__( '1st Icon Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->add_control(
			'team_icon2',
			array(
				'label'       => esc_html__( 'Select 2nd icon', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::ICON,
				'description' => esc_html__( 'Choose an icon for team member icon 1', 'pinkmart' ),
			)
		);
		$this->add_control(
			'team_icon2_url',
			array(
				'label'         => esc_html__( '2nd Icon Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->add_control(
			'team_icon3',
			array(
				'label'       => esc_html__( 'Select 3rd icon', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::ICON,
				'description' => esc_html__( 'Choose an icon for team member icon 1', 'pinkmart' ),
			)
		);
		$this->add_control(
			'team_icon3_url',
			array(
				'label'         => esc_html__( '3rd Icon Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->add_control(
			'team_icon4',
			array(
				'label'       => esc_html__( 'Select 4th icon', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::ICON,
				'description' => esc_html__( 'Choose an icon for team member icon 1', 'pinkmart' ),
			)
		);
		$this->add_control(
			'team_icon4_url',
			array(
				'label'         => esc_html__( '4th Icon Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->add_control(
			'team_icon5',
			array(
				'label'       => esc_html__( 'Select 5th icon', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::ICON,
				'description' => esc_html__( 'Choose an icon for team member icon 1', 'pinkmart' ),
			)
		);
		$this->add_control(
			'team_icon5_url',
			array(
				'label'         => esc_html__( '5th Icon Link', 'pinkmart' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'pinkmart' ),
				'show_external' => true,
				'default'       => array(
					'url' => '#',
				),
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Team Member widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		if ( $settings['team_icon1_url']['is_external'] ) {
			$target1 = '_blank';
		} else {
			$target1 = '_self';
		}

		if ( $settings['team_icon2_url']['is_external'] ) {
			$target2 = '_blank';
		} else {
			$target2 = '_self';
		}

		if ( $settings['team_icon3_url']['is_external'] ) {
			$target3 = '_blank';
		} else {
			$target3 = '_self';
		}

		if ( $settings['team_icon4_url']['is_external'] ) {
			$target4 = '_blank';
		} else {
			$target4 = '_self';
		}

		if ( $settings['team_icon5_url']['is_external'] ) {
			$target5 = '_blank';
		} else {
			$target5 = '_self';
		}

		$shortcode = '[team_member url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" elementor_url_title="' . $settings['elementor_url_title'] . '" description="' . $settings['description'] . '" name="' . $settings['name'] . '" job_title="' . $settings['job_title'] . '" style="' . $settings['style'] . '" image="' . $settings['image']['url'] . '" signature="' . $settings['signature']['url'] . '" team_color="' . $settings['team_color'] . '" team_color_preset="custom" team_icon1="' . $settings['team_icon1'] . '" team_icon_url1="' . $settings['team_icon1_url']['url'] . '" team_icon_target1="' . $target1 . '" team_icon2="' . $settings['team_icon2'] . '" team_icon_url2="' . $settings['team_icon2_url']['url'] . '" team_icon_target2="' . $target2 . '" team_icon3="' . $settings['team_icon3'] . '" team_icon_url3="' . $settings['team_icon3_url']['url'] . '" team_icon_target3="' . $target3 . '" team_icon4="' . $settings['team_icon4'] . '" team_icon_url4="' . $settings['team_icon4_url']['url'] . '" team_icon_target4="' . $target4 . '" team_icon5="' . $settings['team_icon5'] . '" team_icon_url5="' . $settings['team_icon5_url']['url'] . '" team_icon_target5="' . $target5 . '"]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings = $this->get_settings_for_display();
		if ( $settings['team_icon1_url']['is_external'] ) {
			$target1 = '_blank';
		} else {
			$target1 = '_self';
		}

		if ( $settings['team_icon2_url']['is_external'] ) {
			$target2 = '_blank';
		} else {
			$target2 = '_self';
		}

		if ( $settings['team_icon3_url']['is_external'] ) {
			$target3 = '_blank';
		} else {
			$target3 = '_self';
		}

		if ( $settings['team_icon4_url']['is_external'] ) {
			$target4 = '_blank';
		} else {
			$target4 = '_self';
		}

		if ( $settings['team_icon5_url']['is_external'] ) {
			$target5 = '_blank';
		} else {
			$target5 = '_self';
		}

		$shortcode = '[team_member url="' . $settings['url']['url'] . '" new_tab="' . $settings['url']['is_external'] . '" elementor_url_title="' . $settings['elementor_url_title'] . '" description="' . $settings['description'] . '" name="' . $settings['name'] . '" job_title="' . $settings['job_title'] . '" style="' . $settings['style'] . '" image="' . $settings['image']['url'] . '" signature="' . $settings['signature']['url'] . '" team_color="' . $settings['team_color'] . '" team_color_preset="custom" team_icon1="' . $settings['team_icon1'] . '" team_icon_url1="' . $settings['team_icon1_url']['url'] . '" team_icon_target1="' . $target1 . '" team_icon2="' . $settings['team_icon2'] . '" team_icon_url2="' . $settings['team_icon2_url']['url'] . '" team_icon_target2="' . $target2 . '" team_icon3="' . $settings['team_icon3'] . '" team_icon_url3="' . $settings['team_icon3_url']['url'] . '" team_icon_target3="' . $target3 . '" team_icon4="' . $settings['team_icon4'] . '" team_icon_url4="' . $settings['team_icon4_url']['url'] . '" team_icon_target4="' . $target4 . '" team_icon5="' . $settings['team_icon5'] . '" team_icon_url5="' . $settings['team_icon5_url']['url'] . '" team_icon_target5="' . $target5 . '"]';
		echo "$shortcode";

	}

	protected function _content_template() {
		?>
		<# view.addRenderAttribute('team-member-container','class','team-member '+settings.style); #>
		<div {{{view.getRenderAttributeString('team-member-container')}}} >
		<# if (settings.image.url != '') { #>
			<div class="member-pic-container">

				<div class="member-line"></div>

				<div class="member-pic">
					<img class="bg-image" src="{{settings.image.url}}" alt="{{settings.name}}">
				</div>

				<div class="member-plus">
					<span class="member-plus-line"></span>
				</div>
				<# 
				let teamIcons = {
					team_icon1 : settings.team_icon1,
					team_icon2 : settings.team_icon2,
					team_icon3 : settings.team_icon3,
					team_icon4 : settings.team_icon4,
					team_icon5 : settings.team_icon5
				};
				const hasTeamIcon = (key) => teamIcons[key].length != "";
				if (Object.keys(teamIcons).some(key => hasTeamIcon)) {
					#>
					<ul class="icons">
						<#
						Object.keys(teamIcons).map(key => {
							if (teamIcons[key] != "") { 
								let target = (settings[key+'_url']['is_external']) ? "_blank" : "_self";
								view.addRenderAttribute(
									'icon',
									{
										class: settings[key]
									}
								);
								view.addRenderAttribute(
									'icon_url',
									{
										href: settings[key+'_url']['url'],
										title: settings.job_title,
										target: [target]
									}
								);
							#>
							<li>
								<a {{{ view.getRenderAttributeString( 'icon_url' ) }}}>
									<span {{{ view.getRenderAttributeString( 'icon' ) }}}></span>
								</a>
							</li>
							<#
							}
						})
						#>
					</ul>
					<#
				}
				#>
				<div class="overlay"></div>
			</div>
			<div class="member-info">
				<# 
				view.addInlineEditingAttributes('job_title','none');
				view.addInlineEditingAttributes('name','none'); 
				view.addInlineEditingAttributes('description','none');
				view.addRenderAttribute('name','class','member-name');
				#>
				<span {{{ view.getRenderAttributeString('name') }}}>{{{settings.name}}}</span>
				<cite {{{ view.getRenderAttributeString('job_title') }}}>{{settings.job_title}}</cite>
				<div class="member-description">
					<p {{{ view.getRenderAttributeString('description') }}}>{{settings.description}}</p>
					<# 
					if (settings.url.url != "") { 
						let target = (settings.url.is_external) ? "_blank" : "_self";
						view.addRenderAttribute('url',{href: settings.url.url,target:[target],class:"more-link-arrow",title:settings.elementor_url_title});
					#>
						<a {{{view.getRenderAttributeString('url')}}}>[{{settings.elementor_url_title}}]</a>
					<# 
					} 
					if (settings.signature.url != '') {
						#>
						<div class="signature">
							<img src="{{{settings.signature.url}}}" alt="{{settings.name}}">
						</div>
						<#
					}
					#>
				</div>
			</div>
		<# } #>
		</div>
		<?php
	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Team_Member_Widget() );
