<?php
/**
 * Elementor Testimonial Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Kite_Testimonial_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Testimonial widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kite-testimonial';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Testimonial widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial', 'pinkmart' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Testimonial widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-testimonial-carousel kite-element-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Testimonial widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'by-kite' );
	}

	/**
	 * Register Testimonial widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'testimonial_settings',
			array(
				'label' => esc_html__( 'Testimonial Settings', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Style', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'pinkmart' ),
					'light' => esc_html__( 'Light', 'pinkmart' ),
				),
				'default' => 'dark',
			)
		);
		$this->add_control(
			'visible_items',
			array(
				'label'   => esc_html__( 'Column', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => esc_html__( '1', 'pinkmart' ),
					'2' => esc_html__( '2', 'pinkmart' ),
					'3' => esc_html__( '3', 'pinkmart' ),
					'4' => esc_html__( '4', 'pinkmart' ),
				),
				'default' => '2',
			)
		);
		$this->end_controls_section();
		$this->start_controls_section(
			'repeater_section',
			array(
				'label' => esc_html__( 'Testimonial Items', 'pinkmart' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'image_url',
			array(
				'label'   => esc_html__( 'Image URL', 'pinkmart' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);
		$repeater->add_control(
			'author',
			array(
				'label' => esc_html__( 'Name', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'job',
			array(
				'label' => esc_html__( 'Title', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXT,
			)
		);
		$repeater->add_control(
			'text',
			array(
				'label' => esc_html__( 'Statement', 'pinkmart' ),
				'type'  => \Elementor\Controls_Manager::TEXTAREA,
			)
		);
		$this->add_control(
			'testimonial_items',
			array(
				'label'       => esc_html__( 'Testimonial Items', 'pinkmart' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'author' => esc_html__( 'John Doe', 'pinkmart' ),
						'Job'    => esc_html__( 'Executive Manager', 'pinkmart' ),
					),
					array(
						'author' => esc_html__( 'John Doe', 'pinkmart' ),
						'Job'    => esc_html__( 'Executive Manager', 'pinkmart' ),
					),
				),
				'title_field' => '{{{ author }}}',
			)
		);
		$this->end_controls_section();

	}

	/**
	 * Render Testimonial widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings          = $this->get_settings_for_display();
		$testimonial_items = '';
		foreach ( $settings['testimonial_items'] as $item ) {
			$testimonial_items .= '[testimonial_item author="' . $item['author'] . '" job="' . $item['job'] . '" text="' . $item['text'] . '" image_url="' . $item['image_url']['id'] . '"]';
		}
		$shortcode = '[testimonial style="' . $settings['style'] . '" visible_items="' . $settings['visible_items'] . '"]' . $testimonial_items . '[/testimonial]';
		echo do_shortcode( shortcode_unautop( $shortcode ) );
	}

	/**
	 * Whether the reload preview is required or not.
	 *
	 * Used to determine whether the reload preview is required.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return bool Whether the reload preview is required.
	 */
	public function is_reload_preview_required() {
		return false;
	}

	/**
	 * Render shortcode widget as plain content.
	 *
	 * Override the default behavior by printing the shortcode instead of rendering it.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function render_plain_content() {
		// In plain mode, render without shortcode
		$settings          = $this->get_settings_for_display();
		$testimonial_items = '';
		foreach ( $settings['testimonial_items'] as $item ) {
			$testimonial_items .= '[testimonial_item author="' . $item['author'] . '" job="' . $item['job'] . '" text="' . $item['text'] . '" image_url="' . $item['image_url']['url'] . '"]';
		}
		$shortcode = '[testimonial style="' . $settings['style'] . '" visible_items="' . $settings['visible_items'] . '"]' . $testimonial_items . '[/testimonial]';
		echo "$shortcode";
	}

	protected function _content_template() {

	}
}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Kite_Testimonial_Widget() );
